@@ -4,10 +4,9 @@ use strict;
 
 use Carp();
 
-use Rose::Object::MakeMethods;
-our @ISA = qw(Rose::Object::MakeMethods);
+use base 'Rose::Object::MakeMethods';
 
-our $VERSION = '0.54';
+our $VERSION = '0.615';
 
 sub localized_message
 {
@@ -187,12 +186,12 @@ sub localized_error
     {
       my($self) = shift;
 
-      my $localizer = $self->localizer;
-
       if(@_)
       {
         my($id) = shift;
 
+        my $localizer = $self->localizer;
+
         my @args;
 
         if(@_ == 1 && ref($_[0]) =~ /^(?:HASH|ARRAY)$/)
@@ -292,12 +291,12 @@ sub localized_errors
     {
       my($self) = shift;
 
-      my $localizer = $self->localizer;
-
       if(@_)
       {
         return $self->{$key} = undef  unless(defined $_[0]);
 
+        my $localizer = $self->localizer;
+
         if(@_ > 1)
         {
           my($id) = shift;
